@@ -2,9 +2,9 @@ from fulcrum.api import APIConfig
 from fulcrum.api.endpoints import (Forms, Records, Webhooks, Photos,
                                    Memberships, Roles, ChoiceLists,
                                    ClassificationSets, Projects, Videos,
-                                   Changesets)
+                                   Changesets, ChildRecords)
 
-__version__ = '1.2.0'
+__version__ = '1.3.0'
 
 
 class Fulcrum(object):
@@ -21,3 +21,4 @@ class Fulcrum(object):
         self.projects = Projects(api_config=api_config)
         self.videos = Videos(api_config=api_config)
         self.changesets = Changesets(api_config=api_config)
+        self.child_records = ChildRecords(api_config=api_config)
